@@ -41,7 +41,8 @@ typedef struct {
 	const gchar        *(*plugin_get_name) (void);
 	const gchar        *(*plugin_get_description) (void);
 	GList              *(*plugin_get_connection_params) (void);
-	GdaServerProvider * (*plugin_create_provider) (void);
+	GdaServerProvider  *(*plugin_create_provider) (void);
+	gchar              *(*get_dsn_spec) (void);
 } LoadedProvider;
 
 struct _GdaClientPrivate {
@@ -53,7 +54,7 @@ static void gda_client_class_init (GdaClientClass *klass);
 static void gda_client_init       (GdaClient *client, GdaClientClass *klass);
 static void gda_client_finalize   (GObject *object);
 
-static void connection_error_cb (GdaConnection *cnc, GList *error_list, gpointer user_data);
+static void connection_error_cb (GdaConnection *cnc, GdaConnectionEvent *error, GdaClient *client);
 
 enum {
 	EVENT_NOTIFICATION,
@@ -72,8 +73,7 @@ emit_client_error (GdaClient *client, GdaConnection *cnc, const gchar *format, .
 {
 	va_list args;
 	gchar sz[2048];
-	GdaError *error;
-	GList *list;
+	GdaConnectionEvent *error;
 
 	/* build the message string */
 	va_start (args, format);
@@ -83,12 +83,10 @@ emit_client_error (GdaClient *client, GdaConnection *cnc, const gchar *format, .
 	g_print ("Error: %s\n", sz);
 
 	/* create the error list */
-	error = gda_error_new ();
-	gda_error_set_description (error, sz);
-	gda_error_set_source (error, "[GDA client]");
-
-	list = g_list_append (NULL, error);
-	connection_error_cb (cnc, list, client);
+	error = gda_connection_event_new (GDA_CONNECTION_EVENT_ERROR);
+	gda_connection_event_set_description (error, sz);
+	gda_connection_event_set_source (error, "[GDA client]");
+	gda_connection_add_event (cnc, error);
 }
 
 static void
@@ -110,16 +108,12 @@ free_hash_provider (gpointer key, gpointer value, gpointer user_data)
  */
 
 static void
-connection_error_cb (GdaConnection *cnc, GList *error_list, gpointer user_data)
+connection_error_cb (GdaConnection *cnc, GdaConnectionEvent *error, GdaClient *client)
 {
-	GList *l;
-	GdaClient *client = (GdaClient *) user_data;
-
 	g_return_if_fail (GDA_IS_CLIENT (client));
 
-	/* notify actions */
-	for (l = error_list; l != NULL; l = l->next)
-		gda_client_notify_error_event (client, cnc, GDA_ERROR (l->data));
+	/* notify error */
+	gda_client_notify_error_event (client, cnc, error);
 }
 
 static void
@@ -234,6 +228,15 @@ gda_client_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
+/* module error */
+GQuark gda_client_error_quark (void)
+{
+	static GQuark quark;
+	if (!quark)
+		quark = g_quark_from_static_string ("gda_client_error");
+	return quark;
+}
+
 GType
 gda_client_get_type (void)
 {
@@ -309,6 +312,8 @@ find_or_load_provider (GdaClient *client, const gchar *provider)
 			 (gpointer) &prv->plugin_get_connection_params);
 	g_module_symbol (prv->handle, "plugin_create_provider",
 			 (gpointer) &prv->plugin_create_provider);
+	g_module_symbol (prv->handle, "plugin_get_dsn_spec",
+			 (gpointer) &prv->get_dsn_spec);
 	
 	if (!prv->plugin_create_provider) {
 		emit_client_error (client, NULL,
@@ -342,6 +347,7 @@ find_or_load_provider (GdaClient *client, const gchar *provider)
  * @username: user name.
  * @password: password for @username.
  * @options: options for the connection (see #GdaConnectionOptions).
+ * @error: a place to store an error, or %NULL
  *
  * Establishes a connection to a data source. The connection will be opened
  * if no identical connection is available in the #GdaClient connection pool,
@@ -359,7 +365,8 @@ gda_client_open_connection (GdaClient *client,
 			    const gchar *dsn,
 			    const gchar *username,
 			    const gchar *password,
-			    GdaConnectionOptions options)
+			    GdaConnectionOptions options,
+			    GError **error)
 {
 	GdaConnection *cnc = NULL;
 	LoadedProvider *prv;
@@ -371,6 +378,8 @@ gda_client_open_connection (GdaClient *client,
 	dsn_info = gda_config_find_data_source (dsn);
 	if (!dsn_info) {
 		gda_log_error (_("Data source %s not found in configuration"), dsn);
+		g_set_error (error, GDA_CLIENT_ERROR, 0, 
+			     _("Data source %s not found in configuration"), dsn);
 		return NULL;
 	}
 
@@ -392,22 +401,28 @@ gda_client_open_connection (GdaClient *client,
 		if (!prv)
 			prv = find_or_load_provider (client, dsn_info->provider);
 	
-		if (prv)
-			cnc = gda_connection_new (client, prv->provider, dsn, username, password, options);
-		
-		if (!cnc || !GDA_IS_CONNECTION (cnc)) {
-			gda_data_source_info_free (dsn_info);
-			return NULL;
+		if (prv) {
+			cnc = gda_connection_new (client, prv->provider, dsn, username, password, 
+						  options, error);
+
+			if (cnc) {
+				/* add cnc to our private list */
+				client->priv->connections = g_list_append (client->priv->connections, cnc);
+				g_object_weak_ref (G_OBJECT (cnc), (GWeakNotify) cnc_weak_cb, client);
+				g_signal_connect (G_OBJECT (cnc), "error",
+						  G_CALLBACK (connection_error_cb), client);
+			}
 		}
-		
-		/* add list to our private list */
-		client->priv->connections = g_list_append (client->priv->connections, cnc);
-		g_object_weak_ref (G_OBJECT (cnc), (GWeakNotify) cnc_weak_cb, client);
-		g_signal_connect (G_OBJECT (cnc), "error",
-				  G_CALLBACK (connection_error_cb), client);
+		else 
+			g_set_error (error, GDA_CLIENT_ERROR, 0, 
+				     _("Datasource configuration error: could not find provider '%s'"),
+				     dsn_info->provider);
+	}
+	else {
+		g_warning (_("Datasource configuration error: no provider specified"));
+		g_set_error (error, GDA_CLIENT_ERROR, 0, 
+			     _("Datasource configuration error: no provider specified"));
 	}
-	else
-		g_warning ("Provider is null!");
 
 
 	/* free memory */
@@ -422,6 +437,7 @@ gda_client_open_connection (GdaClient *client,
  * @provider_id: provider ID to connect to.
  * @cnc_string: connection string.
  * @options: options for the connection (see #GdaConnectionOptions).
+ * @error: a place to store an error, or %NULL
  *
  * Opens a connection given a provider ID and a connection string. This
  * allows applications to open connections without having to create
@@ -439,7 +455,8 @@ GdaConnection *
 gda_client_open_connection_from_string (GdaClient *client,
 					const gchar *provider_id,
 					const gchar *cnc_string,
-					GdaConnectionOptions options)
+					GdaConnectionOptions options,
+					GError **error)
 {
 	GdaDataSourceInfo *dsn_info;
 	GdaConnection *cnc;
@@ -484,7 +501,8 @@ gda_client_open_connection_from_string (GdaClient *client,
 					  dsn_info->name,
 					  dsn_info->username,
 					  dsn_info->password,
-					  options);
+					  options,
+					  error);
 
 	/* free memory */
 	gda_config_remove_data_source (dsn_info->name);
@@ -494,7 +512,7 @@ gda_client_open_connection_from_string (GdaClient *client,
 }
 
 /**
- * gda_client_get_connection_list
+ * gda_client_get_connections
  * @client: a #GdaClient object.
  *
  * Gets the list of all open connections in the given #GdaClient object.
@@ -504,7 +522,7 @@ gda_client_open_connection_from_string (GdaClient *client,
  * Returns: a GList of #GdaConnection objects.
  */
 const GList *
-gda_client_get_connection_list (GdaClient *client)
+gda_client_get_connections (GdaClient *client)
 {
 	g_return_val_if_fail (GDA_IS_CLIENT (client), NULL);
 	return (const GList *) client->priv->connections;
@@ -624,7 +642,7 @@ gda_client_notify_event (GdaClient *client,
  * Notifies the given #GdaClient of the #GDA_CLIENT_EVENT_ERROR event.
  */
 void
-gda_client_notify_error_event (GdaClient *client, GdaConnection *cnc, GdaError *error)
+gda_client_notify_error_event (GdaClient *client, GdaConnection *cnc, GdaConnectionEvent *error)
 {
 	GdaParameterList *params;
 
@@ -852,18 +870,52 @@ gda_client_rollback_transaction (GdaClient *client, GdaTransaction *xaction)
 }
 
 /**
- * gda_client_get_specs_to_create_database
+ * gda_client_get_dsn_specs
  * @client: a #GdaClient object.
  * @provider: a provider
  *
- * Get an XML string representing the parameters required to create a new database
- * using the @provider provider.
+ * Get an XML string representing the parameters which can be present in the
+ * DSN string used to open a connection.
+ *
+ * Returns: a string (free it after usage), or %NULL if an error occured
+ *
+ */
+gchar *
+gda_client_get_dsn_specs (GdaClient *client, const gchar *provider)
+{
+	LoadedProvider *prv;
+	
+	g_return_val_if_fail (client && GDA_IS_CLIENT (client), NULL);
+	
+	if (!provider || !*provider)
+		return NULL;
+
+	prv = find_or_load_provider (client, provider);
+	if (prv && prv->get_dsn_spec) 
+		return (prv->get_dsn_spec)();
+	else
+		return NULL;
+}
+
+/**
+ * gda_client_get_provider_specs
+ * @client: a #GdaClient object.
+ * @provider: a provider
+ * @type: a #GdaClientSpecsType type
+ *
+ * Get an XML string representing the parameters required to perform a specific action
+ * using the @provider provider. The action to perform is chosen by the @type argument.
+ * 
+ * For example to create a database, make a list of #GdaParameter
+ * objects for each parameter listed in the returned XML string, and use it to call
+ * gda_client_create_database().
  *
  * Returns: a string (free it after usage), or %NULL if the provider does not implement database
  * creation
  */
 gchar *
-gda_client_get_specs_to_create_database (GdaClient *client, const gchar *provider)
+gda_client_get_provider_specs (GdaClient *client, const gchar *provider,
+			       GdaClientSpecsType type)
 {
 	LoadedProvider *prv;
 
@@ -874,7 +926,7 @@ gda_client_get_specs_to_create_database (GdaClient *client, const gchar *provide
 
 	prv = find_or_load_provider (client, provider);
 	if (prv && prv->provider) 
-		return gda_server_provider_get_specs_to_create_database (prv->provider);
+		return gda_server_provider_get_specs (prv->provider, type);
 	else
 		return NULL;
 }
@@ -886,7 +938,16 @@ gda_client_get_specs_to_create_database (GdaClient *client, const gchar *provide
  * @params:
  * @error: a place to store en error, or %NULL
  *
- * Creates a new database using the specifications in @params
+ * Creates a new database using the specifications in @params. The list of parameters to
+ * provide to create a database depends of the provider being used, and can be obtained using
+ * the gda_client_get_provider_specs() function.
+ *
+ * For the providers which do not yet implement the gda_client_get_provider_specs()
+ * method, create a list with a #GdaParameter object for
+ * <ul>
+ *   <li>an opened #GdaConnection object, named "cnc"</li>
+ *   <li>the name of the database to create, named "dbname"</li>
+ * </ul>
  *
  * Returns: TRUE if no error occured and the database has been created
  */
@@ -899,10 +960,94 @@ gda_client_create_database (GdaClient *client, const gchar *provider, GdaParamet
 	g_return_val_if_fail (client && GDA_IS_CLIENT (client), FALSE);
 
 	prv = find_or_load_provider (client, provider);
-	if (prv && prv->provider) 
-		return gda_server_provider_create_database (prv->provider, params, error);
+	if (prv && prv->provider) {
+		/* see if we have only 2 parameters which are "cnc" and "name" */
+		if (params && (gda_parameter_list_get_length (params) == 2)) {
+			GdaParameter *cnc, *name;
+			
+			cnc = gda_parameter_list_find (params, "cnc");
+			name = gda_parameter_list_find (params, "dbname");
+			
+			if (name && cnc) {
+				const GdaValue *cnc_v, *name_v;
+				
+				cnc_v = gda_parameter_get_value (cnc);
+				name_v = gda_parameter_get_value (name);
+				return gda_server_provider_create_database_cnc (prv->provider, 
+										GDA_CONNECTION (gda_value_get_gobject (cnc_v)),
+										gda_value_get_string (name_v));
+			}
+		}
+		else
+			return gda_server_provider_perform_action_params (prv->provider, params, 
+									  GDA_CLIENT_SPECS_CREATE_DATABASE,
+									  error);
+	}
 	else {
-		g_set_error (error, 0, 0, _("Could not find provider %s in the current setup"), provider); 
+		g_set_error (error, GDA_CLIENT_ERROR, 0, 
+			     _("Could not find provider %s in the current setup"), provider); 
 		return FALSE;
 	}
+
+	return FALSE;
+}
+
+/**
+ * gda_client_drop_database
+ * @client: a #GdaClient object.
+ * @provider: a provider
+ * @dbname: the name of the database to destroy
+ * @error: a place to store en error, or %NULL
+ *
+ * Destroys an existing database using the specifications in @params. The list of parameters to
+ * provide to destroy a database depends of the provider being used, and can be obtained using
+ * the gda_client_get_provider_specs() function.
+ *
+ * For the providers which do not yet implement the gda_client_get_provider_specs()
+ * method, create a list with a #GdaParameter object for
+ * <ul>
+ *   <li>an opened #GdaConnection object, named "cnc"</li>
+ *   <li>the name of the database to destroy, named "dbname"</li>
+ * </ul>
+ *
+ * Returns: TRUE if no error occured and the database has been destroyed
+ */
+gboolean
+gda_client_drop_database (GdaClient *client, const gchar *provider, 
+			  GdaParameterList *params, GError **error)
+{
+	LoadedProvider *prv;
+
+	g_return_val_if_fail (client && GDA_IS_CLIENT (client), FALSE);
+
+	prv = find_or_load_provider (client, provider);
+	if (prv && prv->provider) {
+		/* see if we have only 2 parameters which are "cnc" and "name" */
+		if (params && (gda_parameter_list_get_length (params) == 2)) {
+			GdaParameter *cnc, *name;
+			
+			cnc = gda_parameter_list_find (params, "cnc");
+			name = gda_parameter_list_find (params, "dbname");
+			
+			if (name && cnc) {
+				const GdaValue *cnc_v, *name_v;
+				
+				cnc_v = gda_parameter_get_value (cnc);
+				name_v = gda_parameter_get_value (name);
+				return gda_server_provider_drop_database_cnc (prv->provider, 
+									      GDA_CONNECTION (gda_value_get_gobject (cnc_v)),
+									      gda_value_get_string (name_v));
+			}
+		}
+		else
+			return gda_server_provider_perform_action_params (prv->provider, params, 
+									  GDA_CLIENT_SPECS_CREATE_DATABASE, error);
+	}
+	else {
+		g_set_error (error, GDA_CLIENT_ERROR, 0, 
+			     _("Could not find provider %s in the current setup"), provider); 
+		return FALSE;
+	}
+
+	return FALSE;
 }
