@@ -1,9 +1,11 @@
 /* GDA client library
- * Copyright (C) 1998-2002 The GNOME Foundation.
+ * Copyright (C) 1998 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Michael Lausch <michael@lausch.at>
  *	Rodrigo Moya <rodrigo@gnome-db.org>
+ *	Bas Driessen <bas.driessen@xobas.com>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -26,7 +28,8 @@
 
 #include <libgda/gda-command.h>
 #include <libgda/gda-data-model.h>
-#include <libgda/gda-error.h>
+#include <libgda/gda-data-model-index.h>
+#include <libgda/gda-connection-event.h>
 #include <libgda/gda-parameter.h>
 #include <libgda/gda-transaction.h>
 
@@ -46,15 +49,15 @@ typedef struct _GdaServerProvider    GdaServerProvider; /* defined in gda-server
 typedef struct _GdaClient GdaClient; /* defined in gda-client.h */
 
 struct _GdaConnection {
-	GObject object;
+	GObject               object;
 	GdaConnectionPrivate *priv;
 };
 
 struct _GdaConnectionClass {
-	GObjectClass object_class;
+	GObjectClass          object_class;
 
 	/* signals */
-	void (* error) (GdaConnection *cnc, GList *error_list);
+	void (* error) (GdaConnection *cnc, GdaConnectionEvent *error);
 };
 
 GType          gda_connection_get_type (void);
@@ -69,7 +72,9 @@ GdaConnection       *gda_connection_new (GdaClient *client,
 					 const gchar *dsn,
 					 const gchar *username,
 					 const gchar *password,
-					 GdaConnectionOptions options);
+					 GdaConnectionOptions options,
+					 GError **error);
+gboolean             gda_connection_reset (GdaConnection *cnc);
 gboolean             gda_connection_close (GdaConnection *cnc);
 gboolean             gda_connection_is_open (GdaConnection *cnc);
 
@@ -86,31 +91,44 @@ const gchar         *gda_connection_get_provider (GdaConnection *cnc);
 const gchar         *gda_connection_get_username (GdaConnection *cnc);
 const gchar         *gda_connection_get_password (GdaConnection *cnc);
 
-void                 gda_connection_add_error (GdaConnection *cnc, GdaError *error);
-void                 gda_connection_add_error_string (GdaConnection *cnc, const gchar *str, ...);
-void                 gda_connection_add_error_list (GdaConnection *cnc, GList *error_list);
+void                 gda_connection_add_event (GdaConnection *cnc, GdaConnectionEvent *error);
+void                 gda_connection_add_event_string (GdaConnection *cnc, const gchar *str, ...);
+void                 gda_connection_add_events_list (GdaConnection *cnc, GList *events_list);
+void                 gda_connection_clear_events_list (GdaConnection *cnc);
+const GList         *gda_connection_get_events (GdaConnection *cnc);
 
 gboolean             gda_connection_change_database (GdaConnection *cnc, const gchar *name);
-gboolean             gda_connection_create_database (GdaConnection *cnc, const gchar *name);
-gboolean             gda_connection_drop_database (GdaConnection *cnc, const gchar *name);
+gboolean             gda_connection_create_table (GdaConnection *cnc, const gchar *table_name,
+						  const GList *attributes_list,
+						  const GList *index_list);
+gboolean             gda_connection_drop_table (GdaConnection *cnc, const gchar *table_name);
+gboolean             gda_connection_create_index (GdaConnection *cnc, const GdaDataModelIndex *index,
+						  const gchar *table_name);
+gboolean             gda_connection_drop_index (GdaConnection *cnc, const gchar *index_name,
+						gboolean primary_key, const gchar *table_name);
 
 GList               *gda_connection_execute_command (GdaConnection *cnc,
 						     GdaCommand *cmd,
-						     GdaParameterList *params);
+						     GdaParameterList *params,
+						     GError **error);
+gchar               *gda_connection_get_last_insert_id (GdaConnection *cnc, GdaDataModel *recset);
 GdaDataModel        *gda_connection_execute_single_command (GdaConnection *cnc,
 							    GdaCommand *cmd,
-							    GdaParameterList *params);
+							    GdaParameterList *params,
+							    GError **error);
 gint                 gda_connection_execute_non_query (GdaConnection *cnc,
 						       GdaCommand *cmd,
-						       GdaParameterList *params);
+						       GdaParameterList *params,
+						       GError **error);
 
 gboolean             gda_connection_begin_transaction (GdaConnection *cnc, GdaTransaction *xaction);
 gboolean             gda_connection_commit_transaction (GdaConnection *cnc, GdaTransaction *xaction);
 gboolean             gda_connection_rollback_transaction (GdaConnection *cnc, GdaTransaction *xaction);
 
-gboolean             gda_connection_create_blob (GdaConnection *cnc, GdaBlob *blob);
+GdaBlob             *gda_connection_create_blob (GdaConnection *cnc);
+GdaBlob             *gda_connection_fetch_blob_by_id (GdaConnection *cnc, const gchar *sql_id);
 
-const GList         *gda_connection_get_errors (GdaConnection *cnc);
+gchar               *gda_connection_value_to_sql_string (GdaConnection *cnc, GdaValue *from);
 
 typedef enum {
 	GDA_CONNECTION_FEATURE_AGGREGATES,
