@@ -23,6 +23,7 @@
 
 #include <libgda/gda-data-model-array.h>
 #include <libgda/gda-data-model-list.h>
+#include <libgda/gda-data-model-private.h>
 
 #define PARENT_TYPE GDA_TYPE_DATA_MODEL_BASE
 
@@ -55,7 +56,7 @@ gda_data_model_list_get_n_columns (GdaDataModelBase *model)
 	return 1;
 }
 
-static const GdaRow *
+static GdaRow *
 gda_data_model_list_get_row (GdaDataModelBase *model, gint row)
 {
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_LIST (model), NULL);
@@ -78,7 +79,7 @@ gda_data_model_list_is_updatable (GdaDataModelBase *model)
 	return TRUE;
 }
 
-static const GdaRow *
+static GdaRow *
 gda_data_model_list_append_values (GdaDataModelBase *model, const GList *values)
 {
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_LIST (model), NULL);
@@ -108,13 +109,11 @@ gda_data_model_list_class_init (GdaDataModelListClass *klass)
 	object_class->finalize = gda_data_model_list_finalize;
 	model_class->get_n_rows = gda_data_model_list_get_n_rows;
 	model_class->get_n_columns = gda_data_model_list_get_n_columns;
-	model_class->describe_column = NULL;
 	model_class->get_row = gda_data_model_list_get_row;
 	model_class->get_value_at = gda_data_model_list_get_value_at;
 	model_class->is_updatable = gda_data_model_list_is_updatable;
 	model_class->append_values = gda_data_model_list_append_values;
 	model_class->remove_row = gda_data_model_list_remove_row;
-	model_class->update_row = NULL;
 }
 
 static void
@@ -266,11 +265,11 @@ gda_data_model_list_new_from_string_list (const GList *list)
  *
  * Returns: the #GdaRow which has been inserted, or %NULL on failure.
  */
-const GdaRow *
+GdaRow *
 gda_data_model_list_append_value (GdaDataModelList *model, const GdaValue *value)
 {
 	GList *values;
-	const GdaRow *row;
+	GdaRow *row;
 
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_LIST (model), NULL);
 	g_return_val_if_fail (value != NULL, NULL);
