@@ -30,6 +30,17 @@ struct _GdaQuarkList {
 	GHashTable *hash_table;
 };
 
+GType gda_quark_list_get_type (void)
+{
+	static GType our_type = 0;
+
+	if (our_type == 0)
+		our_type = g_boxed_type_register_static ("GdaQuarkList",
+			(GBoxedCopyFunc) gda_quark_list_copy,
+			(GBoxedFreeFunc) gda_quark_list_free);
+	return our_type;
+}
+
 /*
  * Private functions
  */
@@ -41,10 +52,18 @@ free_hash_pair (gpointer key, gpointer value, gpointer user_data)
 	g_free (value);
 }
 
+static void
+copy_hash_pair (gpointer key, gpointer value, gpointer user_data)
+{
+	g_hash_table_insert ((GHashTable *) user_data,
+			     g_strdup ((const char *) key),
+			     g_strdup ((const char *) value));
+}
+
 /**
  * gda_quark_list_new
  *
- * Create a new #GdaQuarkList, which is a set of key->value pairs,
+ * Creates a new #GdaQuarkList, which is a set of key->value pairs,
  * very similar to GLib's GHashTable, but with the only purpose to
  * make easier the parsing and creation of data source connection
  * strings.
@@ -66,7 +85,7 @@ gda_quark_list_new (void)
  * gda_quark_list_new_from_string
  * @string: a connection string.
  *
- * Create a new #GdaQuarkList given a connection string.
+ * Creates a new #GdaQuarkList given a connection string.
  *
  * Returns: the newly created #GdaQuarkList.
  */
@@ -85,9 +104,9 @@ gda_quark_list_new_from_string (const gchar *string)
  * gda_quark_list_clear
  * @qlist: a #GdaQuarkList.
  *
- * Remove all strings in the given #GdaQuarkList.
+ * Removes all strings in the given #GdaQuarkList.
  */
-static void
+void
 gda_quark_list_clear(GdaQuarkList *qlist)
 {
 	g_return_if_fail (qlist != NULL);
@@ -101,7 +120,7 @@ gda_quark_list_clear(GdaQuarkList *qlist)
  * gda_quark_list_free
  * @qlist: a #GdaQuarkList.
  *
- * Release all memory occupied by the given #GdaQuarkList.
+ * Releases all memory occupied by the given #GdaQuarkList.
  */
 void
 gda_quark_list_free (GdaQuarkList *qlist)
@@ -114,14 +133,37 @@ gda_quark_list_free (GdaQuarkList *qlist)
 	g_free (qlist);
 }
 
+
+/**
+ * gda_quark_list_copy
+ * @qlist: quark_list to get a copy from.
+ *
+ * Creates a new #GdaQuarkList from an existing one.
+ * 
+ * Returns: a newly allocated #GdaQuarkList with a copy of the data in @qlist.
+ */
+GdaQuarkList *
+gda_quark_list_copy (GdaQuarkList *qlist)
+{
+	GdaQuarkList *new_qlist;
+
+	g_return_val_if_fail (qlist != NULL, NULL);
+	
+	new_qlist = gda_quark_list_new ();
+	g_hash_table_foreach (qlist->hash_table,
+			      copy_hash_pair,
+			      new_qlist->hash_table);
+	return new_qlist;
+}
+
 /**
  * gda_quark_list_add_from_string
  * @qlist: a #GdaQuarkList.
  * @string: a connection string.
  * @cleanup: whether to cleanup the previous content or not.
  *
- * Add new key->value pairs from the given @string. If @cleanup is
- * set to TRUE, the previous contents will be discarded before adding
+ * Adds new key->value pairs from the given @string. If @cleanup is
+ * set to %TRUE, the previous contents will be discarded before adding
  * the new pairs.
  */
 void
@@ -141,7 +183,7 @@ gda_quark_list_add_from_string (GdaQuarkList *qlist,
 	if (arr) {
 		gint n = 0;
 
-		while (arr[n]) {
+		while (arr[n] && (* (arr[n]))) {
 			gchar **pair;
 
 			pair = (gchar **) g_strsplit (arr[n], "=", 2);
@@ -164,9 +206,9 @@ gda_quark_list_add_from_string (GdaQuarkList *qlist,
  * @qlist: a #GdaQuarkList.
  * @name: the name of the value to search for.
  *
- * Search for the value identified by @name in the given #GdaQuarkList.
+ * Searches for the value identified by @name in the given #GdaQuarkList.
  *
- * Returns: the value associated with the given key if found, or NULL
+ * Returns: the value associated with the given key if found, or %NULL
  * if not found.
  */
 const gchar *
@@ -186,7 +228,7 @@ gda_quark_list_find (GdaQuarkList *qlist, const gchar *name)
  * @qlist: a #GdaQuarkList structure.
  * @name: an entry name.
  *
- * Remove an entry from the #GdaQuarkList, given its name.
+ * Removes an entry from the #GdaQuarkList, given its name.
  */
 void
 gda_quark_list_remove (GdaQuarkList *qlist, const gchar *name)
