@@ -26,7 +26,6 @@
 #  define __gda_mysql_h__
 
 #include <glib/gmacros.h>
-#include <config.h>
 #include <libgda/gda-connection.h>
 #include <libgda/gda-server-provider.h>
 #include <libgda/gda-intl.h>
@@ -43,8 +42,9 @@ G_BEGIN_DECLS
  * Utility functions
  */
 
-GdaError     *gda_mysql_make_error (MYSQL *handle);
-GdaValueType  gda_mysql_type_to_gda (enum enum_field_types mysql_type);
+GdaConnectionEvent     *gda_mysql_make_error (MYSQL *handle);
+GdaValueType  gda_mysql_type_to_gda (enum enum_field_types mysql_type, gboolean is_unsigned);
+gchar        *gda_mysql_type_from_gda (const GdaValueType type);
 
 G_END_DECLS
 
