@@ -80,7 +80,7 @@ const gboolean
 gda_sybase_set_gda_value (GdaSybaseConnectionData *scnc,
                           GdaValue *value, GdaSybaseField *field)
 {
-	GdaError   *error = NULL;
+	GdaConnectionEvent   *error = NULL;
 	gboolean   success = FALSE;
 	
 	g_return_val_if_fail (value != NULL, FALSE);
@@ -92,7 +92,7 @@ gda_sybase_set_gda_value (GdaSybaseConnectionData *scnc,
 			    && GDA_IS_CONNECTION (scnc->gda_cnc)) {
 				error = gda_sybase_make_error (scnc,
 				                               _("Attempt setting a nonnullable field to null."));
-				gda_connection_add_error (scnc->gda_cnc, error);
+				gda_connection_add_event (scnc->gda_cnc, error);
 			} else {
 				sybase_error_msg (_("Attempt setting a nonnullable field to null."));
 			}
@@ -188,7 +188,7 @@ gda_sybase_set_value_general (GdaSybaseConnectionData *scnc,
 	CS_RETCODE ret = CS_SUCCEED;
 	CS_INT     len = 0;
 	gchar      tmp_data[SYBASE_CONVBUF_SIZE];
-	GdaError   *error = NULL;
+	GdaConnectionEvent   *error = NULL;
 
 	g_return_val_if_fail (scnc != NULL, FALSE);
 	g_return_val_if_fail (scnc->gda_cnc != NULL, FALSE);
@@ -207,7 +207,7 @@ gda_sybase_set_value_general (GdaSybaseConnectionData *scnc,
 		error = gda_sybase_make_error (scnc, 
 			_("cslib cannot convert type %d"),
 			field->fmt.datatype);
-		gda_connection_add_error (scnc->gda_cnc, error);
+		gda_connection_add_event (scnc->gda_cnc, error);
 		return FALSE;
 	}
 
@@ -222,7 +222,7 @@ gda_sybase_set_value_general (GdaSybaseConnectionData *scnc,
 		error = gda_sybase_make_error (scnc,
 		        _("data conversion failed for type %d"),
 			field->fmt.datatype);
-		gda_connection_add_error (scnc->gda_cnc, error);
+		gda_connection_add_event (scnc->gda_cnc, error);
 		sybase_check_messages(scnc->gda_cnc);
 		return FALSE;
 	}
