@@ -1,8 +1,9 @@
 /* GDA - Test suite
- * Copyright (C) 1998-2002 The GNOME Foundation
+ * Copyright (C) 1998 - 2005 The GNOME Foundation
  *
  * AUTHORS:
  *	Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,6 +22,7 @@
  */
 
 #include "postgres-test.h"
+#include <string.h>
 
 #define IGNORE_ERR	GDA_COMMAND_OPTION_IGNORE_ERRORS
 #define STOP_ON_ERR	GDA_COMMAND_OPTION_STOP_ON_ERRORS
@@ -36,7 +38,7 @@ execute_non_query (GdaConnection *cnc, const gchar *query)
 				   GDA_COMMAND_TYPE_SQL,
 				   STOP_ON_ERR);
 
-	list = gda_connection_execute_command (cnc, command, NULL);
+	list = gda_connection_execute_command (cnc, command, NULL, NULL);
 	retval = (list == NULL) ? FALSE : TRUE;
 	g_list_foreach (list, (GFunc) g_object_unref, NULL);
 	g_list_free (list);
@@ -123,8 +125,7 @@ select_data (GdaConnection *cnc)
 	select_command = gda_command_new ( "select * from gda_postgres_test",
 					GDA_COMMAND_TYPE_SQL, STOP_ON_ERR);
 
-	list = gda_connection_execute_command (cnc, select_command,
-						NULL);
+	list = gda_connection_execute_command (cnc, select_command, NULL, NULL);
 	gda_command_free (select_command);
 
 	return list;
@@ -174,9 +175,110 @@ print_errors (const GList *list)
 	GList *tmp;
 
 	tmp = (GList *) list;
-	for (tmp = (GList *) list; tmp; tmp = tmp->next)
-		if (tmp->data && *((char *) tmp->data))
-			g_print ("\t\t\t%s\n", (char *) tmp->data);
+	for (tmp = (GList *) list; tmp; tmp = tmp->next) {
+		GdaConnectionEvent *error = GDA_CONNECTION_EVENT (tmp->data);
+		g_print ("\t\t\t%s\n", gda_connection_event_get_description (error));
+	}
+}
+
+static void
+blob_tests (GdaConnection *cnc)
+{
+	GdaBlob *blob;
+	GdaTransaction *xaction;
+	gchar *str = "The string";
+	gchar copy_str [10];
+	gint nbytes;
+	gchar *tmp;
+
+	xaction = gda_transaction_new (NULL);
+
+	gda_connection_begin_transaction (cnc, xaction);
+	blob = gda_connection_create_blob (cnc);
+	g_print ("\t\tCreating a BLOB: ");
+	if (!blob) {
+		g_print ("FAILED\n");
+		print_errors (gda_connection_get_events (cnc));
+	} 
+	else 
+		g_print ("OK\n");
+	
+	g_print ("\t\tOpening a BLOB (read/write): ");
+	if (gda_blob_open (blob, GDA_BLOB_MODE_RDWR)) {
+		g_print ("FAILED\n");
+		print_errors (gda_connection_get_events (cnc));
+	} 
+	else {
+		tmp = gda_blob_get_sql_id (blob);
+		g_print ("OK, blob Oid=%s\n", tmp);
+		g_free (tmp);
+	}
+
+	g_print ("\t\tWriting to BLOB: ");
+	if (gda_blob_write (blob, str, strlen (str), &nbytes)) {
+		g_print ("FAILED\n");
+		print_errors (gda_connection_get_events (cnc));
+	} 
+	else
+		g_print ("OK %d\n", nbytes);
+
+	g_print ("\t\tSeeking: ");
+	if (gda_blob_lseek (blob, 2, SEEK_SET) < 0) {
+		g_print ("FAILED\n");
+		print_errors (gda_connection_get_events (cnc));
+	} 
+	else
+		g_print ("OK\n");
+
+	g_print ("\t\tReading from BLOB: ");
+	if (gda_blob_read (blob, copy_str, strlen (str) - 2, &nbytes)) {
+		g_print ("FAILED\n");
+		print_errors (gda_connection_get_events (cnc));
+	} 
+	else {
+		copy_str [nbytes] = '\0';
+		if (strcmp (copy_str, str + 2)) 
+			g_print ("FAILED\n\t\tExpecting %s but was %s\n", str + 2, copy_str);
+		else
+			g_print ("OK %d\n", nbytes);
+	}
+
+	g_print ("\t\tClosing the BLOB: ");
+	if (gda_blob_close (blob)) {
+		g_print ("FAILED\n");
+		print_errors (gda_connection_get_events (cnc));
+	} else
+		g_print ("OK\n");
+
+	g_object_unref (blob);
+
+	gda_connection_rollback_transaction (cnc, xaction);
+	
+	gda_connection_begin_transaction (cnc, xaction);
+	g_print ("\t\tCreating another BLOB: ");
+	blob = gda_connection_create_blob (cnc);
+	if (!blob) {
+		g_print ("FAILED\n");
+		print_errors (gda_connection_get_events (cnc));
+	} 
+	else {
+		tmp = gda_blob_get_sql_id (blob);
+		g_print ("OK, blob Oid=%s\n", tmp);
+		g_free (tmp);
+	}
+
+	g_print ("\t\tRemoving the BLOB: ");
+	if (gda_blob_remove (blob)) {
+		g_print ("FAILED\n");
+		print_errors (gda_connection_get_events (cnc));
+	} 
+	else
+		g_print ("OK\n");
+
+	gda_connection_rollback_transaction (cnc, xaction);
+
+	g_object_unref (blob);
+	g_object_unref (G_OBJECT (xaction));
 }
 
 /* Postgres provider tests */
@@ -200,7 +302,7 @@ do_postgres_test (GdaConnection *cnc)
 			success ? "OK" : "Error");
 
 	if (!success)
-		print_errors (gda_connection_get_errors (cnc));
+		print_errors (gda_connection_get_events (cnc));
 
 	/* Inserts values */
 	success = insert_data (cnc);
@@ -208,7 +310,7 @@ do_postgres_test (GdaConnection *cnc)
 				 success ? "OK" : "Error");
 
 	if (!success)
-		print_errors (gda_connection_get_errors (cnc));
+		print_errors (gda_connection_get_events (cnc));
 
 	/* Selects values */
 	list = select_data (cnc);
@@ -224,7 +326,7 @@ do_postgres_test (GdaConnection *cnc)
 	g_list_free (list);
 
 	if (!success)
-		print_errors (gda_connection_get_errors (cnc));
+		print_errors (gda_connection_get_events (cnc));
 
 	/* Parent tables */
 	execute_non_query (cnc, "drop table gda_postgres_parent");
@@ -234,11 +336,11 @@ do_postgres_test (GdaConnection *cnc)
 
 	success = execute_non_query (cnc, "drop table gda_postgres_child");
 	if (!success)
-		print_errors (gda_connection_get_errors (cnc));
+		print_errors (gda_connection_get_events (cnc));
 
 	success = execute_non_query (cnc, "drop table gda_postgres_parent");
 	if (!success)
-		print_errors (gda_connection_get_errors (cnc));
+		print_errors (gda_connection_get_events (cnc));
 
 	g_print ("-----------------\n");
 
@@ -252,5 +354,7 @@ do_postgres_test (GdaConnection *cnc)
 	g_list_free (list);
 	/* Clean up */
 	g_print ("\t\tDrop table: %s\n", drop_table (cnc) ? "OK" : "Error");
+
+	blob_tests (cnc);
 }
 
